.. xmltest documentation master file, created by
   sphinx-quickstart on Mon Mar 25 13:25:27 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to xmltest's documentation!
===================================

This is cool.

.. toctree::
   :maxdepth: 2
   :caption: Contents:
   
   getting_started
   modules

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
